Index: src/accessors.cc |
diff --git a/src/accessors.cc b/src/accessors.cc |
index 47b0a856332e24cec0b4ff7e8ab0666d20ca9dc2..daa865400bc2d61dc1ae2bd8de7b8897fadc3e90 100644 |
--- a/src/accessors.cc |
+++ b/src/accessors.cc |
@@ -911,10 +911,10 @@ MaybeObject* Accessors::FunctionGetCaller(Isolate* isolate, |
if (caller->shared()->bound()) { |
return isolate->heap()->null_value(); |
} |
// Censor if the caller is not a classic mode function. |
// Change from ES5, which used to throw, see: |
// https://bugs.ecmascript.org/show_bug.cgi?id=310 |
- if (!caller->shared()->is_classic_mode()) { |
+ if (!caller->shared()->is_sloppy_mode()) { |
return isolate->heap()->null_value(); |
} |
@@ -911,10 +911,10 @@ MaybeObject* Accessors::FunctionGetCaller(Isolate* isolate, |
return isolate->heap()->null_value(); |
} |
- // Censor if the caller is not a classic mode function. |
+ // Censor if the caller is not a sloppy mode function. |
// Change from ES5, which used to throw, see: |
// https://bugs.ecmascript.org/show_bug.cgi?id=310 |